On 3/2/22 11:49, Pali Rohár wrote:
Testes proved that current kwboot version supports also Avanta SoCs.
It looks like that Avanta SoCs are using same kwbimage format as Armada.

Signed-off-by: Pali Rohár <p...@kernel.org>
Tested-by: Tony Dinh <mibo...@gmail.com>

Reviewed-by: Stefan Roese <s...@denx.de>
Tested-by: Stefan Roese <s...@denx.de>

Thanks,
Stefan

---
  doc/kwboot.1   | 2 +-
  tools/kwboot.c | 6 +++---
  2 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/doc/kwboot.1 b/doc/kwboot.1
index bda049bde56f..f555ff26a259 100644
--- a/doc/kwboot.1
+++ b/doc/kwboot.1
@@ -11,7 +11,7 @@ kwboot \- Boot Marvell Kirkwood (and others 32-bit) SoCs over 
a serial link.
  .SH "DESCRIPTION"
The \fBkwboot\fP program boots boards based on Marvell's 32-bit
-platforms including Kirkwood, Dove, A370, AXP, A375, A38x
+platforms including Kirkwood, Dove, Avanta, A370, AXP, A375, A38x
  and A39x over their integrated UART. Boot image files will typically
  contain a second stage boot loader, such as U-Boot. The image file
  must conform to Marvell's BootROM firmware image format
diff --git a/tools/kwboot.c b/tools/kwboot.c
index 11aca00bf1e6..cd1879246a85 100644
--- a/tools/kwboot.c
+++ b/tools/kwboot.c
@@ -1,7 +1,7 @@
  /*
   * Boot a Marvell SoC, with Xmodem over UART0.
  *  supports Kirkwood, Dove, Armada 370, Armada XP, Armada 375, Armada 38x and
  *           Armada 39x
   *
   * (c) 2012 Daniel Stodden <daniel.stod...@gmail.com>
   * (c) 2021 Pali Rohár <p...@kernel.org>
@@ -1990,7 +1990,7 @@ kwboot_usage(FILE *stream, char *progname)
                progname);
        fprintf(stream, "\n");
        fprintf(stream,
-               "  -b <image>: boot <image> with preamble (Kirkwood, Armada 
370/XP/375/38x/39x)\n");
+               "  -b <image>: boot <image> with preamble (Kirkwood, Avanta, Armada 
370/XP/375/38x/39x)\n");
        fprintf(stream,
                "  -D <image>: boot <image> without preamble (Dove)\n");
@@ -1,7 +1,7 @@
  /*
   * Boot a Marvell SoC, with Xmodem over UART0.
- *  supports Kirkwood, Dove, Armada 370, Armada XP, Armada 375, Armada 38x and
- *           Armada 39x
+ *  supports Kirkwood, Dove, Avanta, Armada 370, Armada XP, Armada 375,
+ *           Armada 38x and Armada 39x.
   *
   * (c) 2012 Daniel Stodden <daniel.stod...@gmail.com>
        fprintf(stream, "  -b: enter xmodem boot mode\n");

Viele Grüße,
Stefan Roese

--
DENX Software Engineering GmbH,      Managing Director: Wolfgang Denk
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-51 Fax: (+49)-8142-66989-80 Email: s...@denx.de

Reply via email to